/*
 * Driver include for the RICOH5B Tuner chip.
 *
 * Copyright 2015, 2016 SONY Corporation
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef  _RICOH5B_DEFINE_H
#define  _RICOH5B_DEFINE_H

/******************************************************************************/
/* include file                                                               */
/******************************************************************************/
#include <linux/string.h>
#include "stdrv_if_define.h"
#include "ricoh5b_cfg.h"

/******************************************************************************/
/* object generation control and special settings                             */
/******************************************************************************/
/******************************************************************************/
/* symbolic constant definition                                               */
/******************************************************************************/

#define RICOH5B_NULL              (void *)0
#define RICOH5B_FREQ_UNKNOWN      0xFFFF

/* Band Status */
typedef enum {
  RICOH5B_BAND_IDLE  = STDRV_BAND_IDLE,  //!< :Default State (BAND is not selected)
  RICOH5B_BAND_FM    = STDRV_BAND_FM,    //!< :FM
  RICOH5B_BAND_AM    = STDRV_BAND_AM     //!< :AM
} RICOH5B_BAND_STATUS;

/* Initialize done/not status */
typedef enum {
  RICOH5B_INIT_NOT,
  RICOH5B_INIT_DONE
} RICOH5B_INIT_STATUS;

/* seek status */
typedef enum {
  RICOH5B_SEEK_OFF,
  RICOH5B_SEEK_ON
} RICOH5B_SEEK_STATUS;

/* audio output volume */
typedef enum
{
  RICOH5B_VOLUME_0DB        = STDRV_VOLUME_0DB,        //!< :0dB
  RICOH5B_VOLUME_MINUS_3DB  = STDRV_VOLUME_MINUS_3DB,  //!< :-3dB
  RICOH5B_VOLUME_MINUS_4DB  = STDRV_VOLUME_MINUS_4DB,  //!< :-4dB
  RICOH5B_VOLUME_MINUS_5DB  = STDRV_VOLUME_MINUS_5DB,  //!< :-5dB
  RICOH5B_VOLUME_UNKNOWN    = STDRV_VOLUME_UNKNOWN     //!< :unknown
} RICOH5B_VOLUME;

/* immunity measure ENABLE / DISABLE */
typedef enum
{
  RICOH5B_IMMUNITY_DISABLE    = STDRV_IMMUNITY_DISABLE,    //!< :Immunity Measure is DISABLE
  RICOH5B_IMMUNITY_ENABLE     = STDRV_IMMUNITY_ENABLE,     //!< :Immunity Measure is ENABLE
  RICOH5B_IMMUNITY_ENABLE_KR  = STDRV_IMMUNITY_ENABLE_KR,  //!< :Immunity Measure is ENABLE for KOREA
  RICOH5B_IMMUNITY_UNKNOWN    = STDRV_IMMUNITY_UNKNOWN     //!< :unknown
} RICOH5B_IMMUNITY;

typedef enum {
  RICOH5B_IF_200K,
  RICOH5B_IF_300K,
  RICOH5B_IF_400K
} RICOH5B_IF_TYPE;

#endif  /* _RICOH5B_DEFINE_H */
/* end of ricoh5b_define.h */
